@@ -307,7 +307,7 @@ class HardwareStats(models.Model):
 
 
 
-class DataTransformer(models.Model):
+class DataTransformer(MPTTModel):
     id = models.UUIDField(primary_key=True, default=uuid.uuid4)
     accessory = models.ForeignKey(
         Accessory,
@@ -316,6 +316,7 @@ class DataTransformer(models.Model):
         null=False
     )
     type = models.CharField(max_length=255,  blank=True, null=True, default=None)
+    parent = TreeForeignKey('self', on_delete=models.CASCADE, null=True, blank=True, related_name='children')
     updated_at = models.DateTimeField(auto_now=True)
     created_at = models.DateTimeField(auto_now_add=True)
 
@@ -331,8 +332,9 @@ class DataTransformer(models.Model):
             models.Index(fields=['id','accessory']),
         ]
 
-TreeForeignKey(DataTransformer, on_delete=models.CASCADE, blank=True, null=True).contribute_to_class(DataTransformer, 'parent')
-mptt.register(DataTransformer)
+    class MPTTMeta:
+        order_insertion_by=['']
+
 
 class DataTransformerConstants(models.Model):
     id = models.UUIDField(primary_key=True, default=uuid.uuid4)
